# Changelog

## v0.2.0-rc.1 - 2026-02-10

### Chores
- No user-facing changes.

## Unreleased

### Breaking

- Replaced public app entrypoint `App()` with `Vyro()` (hard cut, no alias).

### Features

- Added official `vyro` CLI with `new`, `run`, `dev`, `check`, `test`, `build`, `version`, `doctor`, and `release notes` commands.
